/*
 * Copyright 2002 Oskar Ojala, Yrj Kari-Koskinen and Henri Sivonen.
 *
 * The contents of this file are subject to the Artistic License.
 * You may not use this file except in compliance with the Artistic
 * License (which you should have received along with this file).
 */

package dualroids;

import java.awt.*;
import java.awt.event.*;

import javax.swing.*;
import javax.swing.event.*;

/**
 * The game window. Draws the window that the
 * actual game will be displayed in and adds the <code>InputHandler</code>
 * for handling key events in the window.
 *
 * @author Oskar Ojala, omojala@cc.hut.fi
 * @author Henri Sivonen, hsivonen@iki.fi
 * @author Yrj Kari-Koskinen, yrjo.kari-koskinen@hut.fi
 */
public final class GameFrame extends JFrame {

    /**
     * The single instance of <code>GameFrame</code>
     */
    private static GameFrame theInstance;

    /**
     * Contructs a new <code>GameFrame</code>.
     *
     * @param cmc the <code>ClientModelConnector</code> associated
     *            with this <code>GameFrame</code>
     */
    private GameFrame(ClientModelConnector cmc) {
        this.setTitle("Dualroids");

        // the window size is now unchangeable
        this.setSize(SpaceArea.WINDOW_WIDTH, SpaceArea.WINDOW_HEIGHT);
        this.setResizable(false);

        SpaceArea framedArea = new SpaceArea(cmc);
        this.getContentPane().add(framedArea);
        cmc.registerSpaceArea(framedArea);

        InputHandler ih = cmc.getInputHandler();
        this.addKeyListener(ih);
        this.addWindowListener(ih);
        this.pack();
    }


    /**
     * This assures that no one can create more than one instance 
     * of GameFrame (singleton pattern)
     *
     * @return the instance, or <code>null</code>, if GameFrame has not been
     * properly constructed
     */
    public static GameFrame getInstance() {
        return theInstance;
    }

    /**
     * This assures that no one can create more than one instance 
     * of GameFrame (singleton pattern)
     *
     * @param cmc the <code>ClientModelConnector</code> for 
     * <code>GameFrame</code>'s constructor
     *
     * @return if theInstance is <code>null</code>, it's created and returned
     * otherwise the previously created instance is returned
     */
    public static GameFrame getInstance(ClientModelConnector cmc) {
        if (theInstance == null) {
            theInstance = new GameFrame(cmc);
        }
        return theInstance;
    }
}

