/*
 * Copyright 2002 Henri Sivonen.
 *
 * The contents of this file are subject to the Artistic License.
 * You may not use this file except in compliance with the Artistic
 * License (which you should have received along with this file).
 */

package dualroids;

import java.io.*;
import java.util.*;

/**
 * A class for handling the high score file.
 *
 * @author Henri Sivonen, hsivonen@iki.fi
 */
public final class HighScoreHandler {

    /**
     * The name of the high score file.
     */
    private static final String scoreFile = "dualroids-scores.dat";

    /**
     * The table of the names of the famed players
     */
    String[] names;

    /**
     * The table of the points of the famed players
     */
    int[] points;

    /**
     * Constucts a new <code>HighScoreHandler</code> and does the file IO.
     *
     * @param cmc the <code>ClientModelConnector</code> holding the scores
     *            of the current game
     */
    public HighScoreHandler(ClientModelConnector cmc) {
        this.names = new String[5];
        this.points = new int[5];
        try {
            BufferedReader in = new BufferedReader(new InputStreamReader(new FileInputStream(scoreFile), "UTF-8"));
            String line;
            StringTokenizer st;
            for(int i = 0; i < 5; i++) {
                try {
                    line = in.readLine();
                    st = new StringTokenizer(line, "\t");
                    this.names[i] = st.nextToken();
                    this.points[i] = Integer.parseInt(st.nextToken());
                } catch(Exception e) {
                    this.names[i] = " ";
                    this.points[i] = 0;
                }
            }
            in.close();
        } catch(IOException ioe) {
            for(int i = 0; i < 5; i++) {
                this.names[i] = " ";
                this.points[i] = 0;
            }
        }

        for(int i = 0; i < 2; i++) {
            String name = cmc.getPlayerName(i);
            int score = cmc.getScore(i);
            for(int j = 4; j > -1; j--) {
                if(score > this.points[j]) {
                    if(j != 4) {
                        this.points[j + 1] = this.points[j];
                        this.names[j + 1] = this.names[j];
                    }
                    this.names[j] = name;
                    this.points[j] = score;
                }
            }
        }

        try {
            BufferedWriter out = new BufferedWriter(new OutputStreamWriter(new FileOutputStream(scoreFile), "UTF-8"));
            String line;
            for(int i = 0; i < 5; i++) {
                line = this.names[i] + '\t' + this.points[i];
                out.write(line, 0, line.length());
                out.write("\n", 0, 1); // LF
            }
            out.flush();
            out.close();
        } catch(IOException ioe) {
            Runner.fatalError("High score file could not be written!\n" +
                              ioe.getMessage());
        }
    }

    /**
     * Returns the table of the names of the famed players
     * @return the table of the names of the famed players
     */
    public String[] getNames() {
        return this.names;
    }

    /**
     * Returns the table of the points of the famed players
     * @return the table of the points of the famed players
     */
    public int[] getPoints() {
        return this.points;
    }
}
